@@ -46,8 +46,8 @@ class Workbook(xmlwriter.XMLwriter):
         super(Workbook, self).__init__()
 
         self.filename = filename
-        self.tempdir = None
-        self.date_1904 = 0
+        self.tmpdir = options.get('tmpdir', None)
+        self.date_1904 = options.get('date_1904', False)
         self.worksheet_meta = WorksheetMeta()
         self.selected = 0
         self.fileclosed = 0
@@ -82,7 +82,6 @@ class Workbook(xmlwriter.XMLwriter):
         self.window_width = 16095
         self.window_height = 9660
         self.tab_ratio = 500
-        self.table_count = 0
         self.str_table = SharedStringTable()
         self.vba_project = None
         self.vba_codename = None
@@ -111,18 +110,15 @@ class Workbook(xmlwriter.XMLwriter):
         sheet_index = len(self.worksheets_objs)
         name = self._check_sheetname(name)
 
-        # TODO port these during integration tests.
-        #            self.table_count,
-        #            self.date_1904,
-        #            self.palette, # remove
-        #            self.tempdir,
-
+        # Initialisation data to pass to the worksheet.
         init_data = {
             'name': name,
             'index': sheet_index,
             'str_table': self.str_table,
             'worksheet_meta': self.worksheet_meta,
             'optimization': self.optimization,
+            'tmpdir': self.tmpdir,
+            'date_1904': self.date_1904,
         }
 
         worksheet = Worksheet()
@@ -288,7 +284,7 @@ class Workbook(xmlwriter.XMLwriter):
 
     def _store_workbook(self):
         # Assemble worksheets into a workbook.
-        temp_dir = tempfile.mkdtemp()
+        temp_dir = tempfile.mkdtemp(dir=self.tmpdir)
         packager = Packager()
 
         # Add a default worksheet if non have been added.
@@ -1017,3 +1013,4 @@ class WorksheetMeta(object):
     def __init__(self):
         self.activesheet = 0
         self.firstsheet = 0
+        self.table_count = 0
